ProSHADE: Class Members - Functions

| ProSHADE 0.7.5.4 (MAR 2021) Protein Shape Detection

### - c -

- centreMapOnCOM() : ProSHADE_internal_data::ProSHADE_data
- checkIfPeakBelongs() : ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup
- computeCornerPositions() : ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup
- computeOptimalTranslation() : ProSHADE_internal_data::ProSHADE_data
- computePdbRotationCentre() : ProSHADE_internal_data::ProSHADE_data
- computeRotatedSH() : ProSHADE_internal_data::ProSHADE_data
- computeRotationFunction() : ProSHADE_internal_data::ProSHADE_data
- computeRRPMatrices() : ProSHADE_internal_data::ProSHADE_data
- computeSphericalHarmonics() : ProSHADE_internal_data::ProSHADE_data
- computeTranslationMap() : ProSHADE_internal_data::ProSHADE_data
- convertRotationFunction() : ProSHADE_internal_data::ProSHADE_data
- createNewMapFromBounds() : ProSHADE_internal_data::ProSHADE_data